RankBasedEvaluator
==================

.. currentmodule:: pykeen.evaluation

.. autoclass:: RankBasedEvaluator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RankBasedEvaluator.clear
      ~RankBasedEvaluator.finalize
      ~RankBasedEvaluator.finalize_multi
      ~RankBasedEvaluator.finalize_with_confidence
      ~RankBasedEvaluator.process_scores_

   .. rubric:: Methods Documentation

   .. automethod:: clear
   .. automethod:: finalize
   .. automethod:: finalize_multi
   .. automethod:: finalize_with_confidence
   .. automethod:: process_scores_
